@@ -152,7 +152,7 @@ If the source format is 1.0 and the version number is absent, this
 will return false (as native packages are a lot rarer than non-native
 ones).
 
-Note if the source format is missing, it is assumed to be an 1.0
+Note if the source format is missing, it is assumed to be a 1.0
 package.
 
 Needs-Info requirements for using I<native>: L<Same as field|Lintian::Collect/field ([FIELD[, DEFAULT]])>
@@ -171,7 +171,7 @@ sub native {
         $self->{native} = 1;
     } else {
         my $version = $self->field('version');
-        my $base_dir = $self->base_dir();
+        my $base_dir = $self->base_dir;
         if (defined $version) {
             $version =~ s/^\d+://;
             my $name = $self->{name};
@@ -221,8 +221,8 @@ Needs-Info requirements for using I<binary_package_type>: L<Same as binary_field
 sub binary_package_type {
     my ($self, $binary) = @_;
     if (exists $self->{binaries}) {
-        return $self->{binaries}->{$binary}
-          if exists $self->{binaries}->{$binary};
+        return $self->{binaries}{$binary}
+          if exists $self->{binaries}{$binary};
         return;
     }
     # we need the binary fields for this.
@@ -463,8 +463,8 @@ Needs-Info requirements for using I<binary_relation>: L<Same as binary_field|/bi
 sub binary_relation {
     my ($self, $package, $field) = @_;
     $field = lc $field;
-    return $self->{binary_relation}->{$package}->{$field}
-      if exists $self->{binary_relation}->{$package}->{$field};
+    return $self->{binary_relation}{$package}{$field}
+      if exists $self->{binary_relation}{$package}{$field};
 
     my %special = (
         all    => [qw(pre-depends depends recommends suggests)],
@@ -483,7 +483,7 @@ sub binary_relation {
         my $value = $self->binary_field($package, $field);
         $result = Lintian::Relation->new($value);
     }
-    $self->{binary_relation}->{$package}->{$field} = $result;
+    $self->{binary_relation}{$package}{$field} = $result;
     return $result;
 }
 
@@ -517,7 +517,7 @@ Needs-Info requirements for using I<relation>: L<Same as field|Lintian::Collect/
 sub relation {
     my ($self, $field) = @_;
     $field = lc $field;
-    return $self->{relation}->{$field} if exists $self->{relation}->{$field};
+    return $self->{relation}{$field} if exists $self->{relation}{$field};
 
     my $result;
     if ($field =~ /^build-(depends|conflicts)-all$/) {
@@ -537,30 +537,19 @@ sub relation {
 =item relation_noarch (FIELD)
 
 The same as L</relation (FIELD)>, but ignores architecture
-restrictions in the FIELD field.
+restrictions and build profile restrictions in the FIELD field.
 
-Needs-Info requirements for using I<relation_noarch>: L<Same as field|Lintian::Collect/field ([FIELD[, DEFAULT]])>
+Needs-Info requirements for using I<relation_noarch>: L<Same as relation|Lintian::Collect/relation (FIELD)>
 
 =cut
 
 sub relation_noarch {
     my ($self, $field) = @_;
     $field = lc $field;
-    return $self->{relation_noarch}->{$field}
-      if exists $self->{relation_noarch}->{$field};
+    return $self->{relation_noarch}{$field}
+      if exists $self->{relation_noarch}{$field};
 
-    my $result;
-    if ($field =~ /^build-(depends|conflicts)-all$/) {
-        my $type = $1;
-        my @fields = ("build-$type", "build-$type-indep", "build-$type-arch");
-        $result
-          = Lintian::Relation->and(map { $self->relation_noarch($_) } @fields);
-    } elsif ($field =~ /^build-(depends|conflicts)(?:-(?:arch|indep))?$/) {
-        my $value = $self->field($field);
-        $result = Lintian::Relation->new_noarch($value);
-    } else {
-        croak("unknown relation field $field");
-    }
+    my $result = $self->relation($field)->restriction_less;
     $self->{relation_noarch}{$field} = $result;
     return $result;
 }
